@@ -26,6 +26,7 @@ Usage:
     q.approve("job-id", "reason")
 """
 
+import sys
 from pathlib import Path
 from typing import Optional, Union
 from uuid import UUID
@@ -35,6 +36,41 @@ from loguru import logger
 from .client import CodeQueueClient, create_client
 from .models import CodeJob, JobCollection, JobStatus, QueueConfig
 
+# Global VERBOSE flag to control logging level
+VERBOSE = False
+
+
+def _configure_logging():
+    """Configure logging based on VERBOSE flag."""
+    # Remove default logger first
+    logger.remove()
+
+    if VERBOSE:
+        # Verbose mode: show DEBUG and above
+        logger.add(
+            sink=lambda msg: print(msg, end=""),
+            level="DEBUG",
+            format="<green>{time:YYYY-MM-DD HH:mm:ss.SSS}</green> | <level>{level: <8}</level> | <cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>",
+        )
+    else:
+        # Quiet mode: only show WARNING and above
+        logger.add(
+            sink=lambda msg: print(msg, end=""),
+            level="WARNING",
+            format="<level>{level}</level>: {message}",
+        )
+
+
+def set_verbose(enabled: bool):
+    """Set verbose logging on or off."""
+    global VERBOSE
+    VERBOSE = enabled
+    _configure_logging()
+
+
+# Configure logging on import
+_configure_logging()
+
 # Runner components moved to syft-simple-runner package
 # App execution moved to syft-simple-runner package
 
@@ -45,13 +81,67 @@ except ImportError:
 
     class MockSyftBoxClient:
         def __init__(self):
-            self.email = "demo@example.com"
+            self.email = self._detect_user_email()
+
+        def _detect_user_email(self):
+            """Try to detect the user's email from SyftBox directory structure."""
+            import os
+
+            # Try to find user's own datasite directory
+            possible_datasites_dirs = [
+                Path.home() / "SyftBox" / "datasites",
+                Path("/Users") / os.getlogin() / "SyftBox" / "datasites"
+                if hasattr(os, "getlogin")
+                else None,
+            ]
+
+            for datasites_dir in possible_datasites_dirs:
+                if datasites_dir and datasites_dir.exists():
+                    # First try to find liamtrask@gmail.com specifically
+                    liam_email = "liamtrask@gmail.com"
+                    if (datasites_dir / liam_email).exists():
+                        return liam_email
+
+                    # Look for common user email patterns in datasite names
+                    # Check if there's a datasite that looks like it could be the current user's
+                    for datasite in datasites_dir.iterdir():
+                        if datasite.is_dir():
+                            datasite_name = datasite.name.lower()
+                            # Check for common patterns that might indicate the current user
+                            if any(pattern in datasite_name for pattern in ["liam", "trask"]):
+                                return datasite.name
+
+            # Fallback to demo email
+            return "demo@example.com"
 
         def app_data(self, app_name):
             import tempfile
 
             return Path(tempfile.gettempdir()) / f"syftbox_demo_{app_name}"
 
+        @property
+        def datasites(self):
+            """Return the SyftBox datasites directory if it exists, otherwise a temp directory."""
+            import os
+
+            # Try to find the actual SyftBox directory
+            possible_paths = [
+                Path.home() / "SyftBox" / "datasites",
+                Path("/Users") / os.getlogin() / "SyftBox" / "datasites"
+                if hasattr(os, "getlogin")
+                else None,
+                Path("/tmp/syftbox_demo_datasites"),  # Fallback
+            ]
+
+            for path in possible_paths:
+                if path and path.exists():
+                    return path
+
+            # Create a fallback temp directory
+            fallback = Path("/tmp/syftbox_demo_datasites")
+            fallback.mkdir(exist_ok=True)
+            return fallback
+
         @classmethod
         def load(cls):
             return cls()
@@ -104,6 +194,7 @@ class UnifiedAPI:
         status: Optional[JobStatus] = None,
         target_email: Optional[str] = None,
         limit: int = 50,
+        search_all_datasites: bool = False,
     ) -> list[CodeJob]:
         """
         List jobs matching the given criteria.
@@ -112,6 +203,7 @@ class UnifiedAPI:
             status: Optional filter by job status
             target_email: Optional filter by target datasite
             limit: Maximum number of jobs to return
+            search_all_datasites: If True, search across all datasites instead of just local queue
 
         Returns:
             List of CodeJob objects matching the criteria
@@ -119,7 +211,12 @@ class UnifiedAPI:
         if self.client is None:
             return []
 
-        jobs = self.client.list_jobs(target_email=target_email, status=status, limit=limit)
+        jobs = self.client.list_jobs(
+            target_email=target_email,
+            status=status,
+            limit=limit,
+            search_all_datasites=search_all_datasites,
+        )
         return [self._connect_job_apis(job) for job in jobs]
 
     # Object-Oriented Properties
@@ -129,7 +226,8 @@ class UnifiedAPI:
         """Jobs I've submitted to other people."""
         if self.client is None:
             return JobCollection([])
-        jobs = self.list_jobs()
+        # Search across all datasites since jobs are stored in target's datasite
+        jobs = self.list_jobs(search_all_datasites=True)
         return self._connect_jobs_apis([j for j in jobs if j.requester_email == self.email])
 
     @property
@@ -155,13 +253,23 @@ class UnifiedAPI:
         """Jobs I've submitted that have completed."""
         return self.jobs_for_others.by_status(JobStatus.completed)
 
+    @property
+    def pending_for_others(self) -> JobCollection:
+        """Jobs I've submitted to others that are still pending approval."""
+        return self.jobs_for_others.by_status(JobStatus.pending)
+
     @property
     def pending_for_me(self) -> JobCollection:
         """Jobs submitted to me that need approval."""
-        # Filter out jobs that have been locally updated to non-pending status
-        all_jobs_for_me = self.jobs_for_me
-        pending_jobs = [job for job in all_jobs_for_me if job.status == JobStatus.pending]
-        return JobCollection(pending_jobs)
+        if self.client is None:
+            return JobCollection([])
+
+        # Use the same approach as jobs_for_me but filter by pending status
+        jobs = self.list_jobs()
+        pending_jobs = [
+            j for j in jobs if j.target_email == self.email and j.status == JobStatus.pending
+        ]
+        return self._connect_jobs_apis(pending_jobs)
 
     @property
     def approved_by_me(self) -> JobCollection:
@@ -197,7 +305,7 @@ class UnifiedAPI:
         """
         if self.client is None:
             raise RuntimeError("API not properly initialized")
-        job = self.client.submit_job(target_email, code_folder, name, description, tags)
+        job = self.client.submit_code(target_email, code_folder, name, description, tags)
         return self._connect_job_apis(job)
 
     def submit_python(
@@ -326,6 +434,88 @@ class UnifiedAPI:
         connected_job = self._connect_job_apis(job)
         return connected_job.review()
 
+    def inspect_job(self, job_uid: Union[str, UUID]) -> None:
+        """Print a detailed code review of a job (functional API)."""
+        job = self.get_job(job_uid)
+        if not job:
+            print(f"❌ Job {job_uid} not found")
+            return
+
+        print(f"🔍 Code Review for Job: {job.name}")
+        print(f"📧 Requested by: {job.requester_email}")
+        print(f"📝 Description: {job.description or 'No description provided'}")
+        print(f"🏷️ Tags: {job.tags or 'No tags'}")
+        print("=" * 60)
+
+        # Get file structure
+        files = job.list_files()
+        if files:
+            print(f"📁 Files in job ({len(files)} total):")
+            for file in files:
+                print(f"  📄 {file}")
+            print()
+
+            # Show run script if it exists
+            run_scripts = [f for f in files if f in ["run.sh", "run.py", "run.bash"]]
+            if run_scripts:
+                for script in run_scripts:
+                    print(f"🚀 Execution Script: {script}")
+                    print("-" * 40)
+                    content = job.read_file(script)
+                    if content:
+                        print(content)
+                    else:
+                        print("❌ Could not read script content")
+                    print("-" * 40)
+                    print()
+
+            # Show other important files
+            important_files = [
+                f
+                for f in files
+                if f.endswith((".py", ".txt", ".md", ".yml", ".yaml", ".json", ".csv"))
+                and f not in run_scripts
+            ]
+            if important_files:
+                print("📋 Other important files:")
+                for file in important_files[:5]:  # Show first 5 files
+                    print(f"\n📄 {file}:")
+                    print("-" * 30)
+                    content = job.read_file(file)
+                    if content:
+                        lines = content.split("\n")
+                        if len(lines) > 20:
+                            print("\n".join(lines[:20]))
+                            print(f"... ({len(lines) - 20} more lines)")
+                        else:
+                            print(content)
+                    else:
+                        print("❌ Could not read file content")
+                    print("-" * 30)
+
+                if len(important_files) > 5:
+                    print(f"\n... and {len(important_files) - 5} more files")
+        else:
+            print("❌ No files found in job")
+
+        print("\n" + "=" * 60)
+        print("💡 To approve: job.approve('reason')")
+        print("💡 To reject: job.reject('reason')")
+
+    def read_job_file(self, job_uid: Union[str, UUID], filename: str) -> Optional[str]:
+        """Read a specific file from a job (functional API)."""
+        job = self.get_job(job_uid)
+        if not job:
+            return None
+        return job.read_file(filename)
+
+    def list_job_files(self, job_uid: Union[str, UUID]) -> list[str]:
+        """List all files in a job (functional API)."""
+        job = self.get_job(job_uid)
+        if not job:
+            return []
+        return job.list_files()
+
     # Status and Summary
 
     def status(self) -> dict:
@@ -346,65 +536,40 @@ class UnifiedAPI:
         pass
 
     def help(self):
-        """Show help and examples for using syft-code-queue."""
-        help_text = """
-🚀 Syft Code Queue Help
+        """Show focused help for core workflow methods."""
+        help_text = f"""
+🎯 SyftBox Code Queue v{__version__} - Core Workflow
 
-Import Convention:
-  import syft_code_queue as q
+📤 Submit Jobs:
+  q.submit_job("owner@org.com", "./my_analysis", "Statistical Analysis")
+  q.submit_python("owner@org.com", "print('hello')", "Quick Script")
+  q.submit_bash("owner@org.com", "ls -la", "Directory Listing")
 
-Object-Oriented API (Recommended):
-  # Submit jobs
-  job = q.submit_job("data-owner@university.edu", "./my_analysis", "Statistical Analysis")
-  job = q.submit_script("owner@email.com", "print('hello')", "Hello Test")
+📋 Job Collections:
+  q.pending_for_me               # Jobs waiting for my approval (Data Owner)
+  q.pending_for_others           # Jobs I submitted that are pending (Data Scientist)
+  q.jobs_for_me                  # All jobs submitted to me
+  q.jobs_for_others              # All jobs I've submitted to others
 
-  # Access job collections
-  q.jobs_for_others              # Jobs I've submitted to others
-  q.jobs_for_me                  # Jobs submitted to me
-  q.pending_for_me               # Jobs waiting for my approval
-  q.my_pending                   # My jobs still pending approval
-  q.my_running                   # My jobs currently running
-  q.my_completed                 # My completed jobs
+✅ Job Management:
+  q.approve("job-id", "Looks safe")     # Approve job
+  q.reject("job-id", "Too broad")       # Reject job
 
-  # Work with individual jobs
+🔍 Basic Monitoring:
+  q.get_job("job-id")                   # Get specific job details
+  q.wait_for_completion("job-id")       # Wait for job to finish
+
+💡 Object-Oriented Usage:
   q.jobs_for_me[0].approve("Looks safe")
-  q.jobs_for_me[0].reject("Too broad")
-  q.jobs_for_others[0].get_logs()
+  q.pending_for_others.summary()
   q.jobs_for_others[0].wait_for_completion()
 
-  # Work with collections
-  q.pending_for_me.approve_all("Batch approval")
-  q.jobs_for_me.pending().approve_all("All look good")
-  q.jobs_for_others.by_tags("statistics").summary()
-
-  # Filter collections
-  q.jobs_for_me.by_status(q.JobStatus.completed)
-  q.jobs_for_others.by_name("analysis")
-  q.jobs_for_me.pending()
-  q.jobs_for_others.completed()
-
-Functional API (Legacy):
-  # Submit jobs
-  job = q.submit_job("data-owner@university.edu", "./my_analysis", "Statistical Analysis")
-
-  # Monitor your submitted jobs
-  q.my_jobs()                    # All your jobs
-  q.get_job("job-id")           # Specific job
-  q.get_job_logs("job-id")      # Job logs
-  q.wait_for_completion("job-id") # Wait for completion
-
-  # Manage jobs submitted to you
-  q.all_jobs_for_me()           # All jobs submitted to you
-  q.approve("job-id", "Looks safe")  # Approve job
-  q.reject("job-id", "Too broad")    # Reject job
-
-General:
-  q.status()                    # Overall status summary
-  q.help()                      # This help message
-
-Job Lifecycle:
+📊 Job Lifecycle:
   📤 submit → ⏳ pending → ✅ approved → 🏃 running → 🎉 completed
                        ↘ 🚫 rejected            ↘ ❌ failed
+
+🔧 Need more methods? All advanced features are still available, just not in autocomplete.
+   Use q.VERBOSE=True for debugging. See documentation for full API.
         """
         print(help_text)
 
@@ -425,6 +590,9 @@ all_jobs_for_me = jobs.all_jobs_for_me
 approve = jobs.approve
 reject = jobs.reject
 review_job = jobs.review_job
+inspect_job = jobs.inspect_job
+read_job_file = jobs.read_job_file
+list_job_files = jobs.list_job_files
 status = jobs.status
 help = jobs.help
 
@@ -438,6 +606,8 @@ def __getattr__(name):
         return jobs.jobs_for_me
     elif name == "pending_for_me":
         return jobs.pending_for_me
+    elif name == "pending_for_others":
+        return jobs.pending_for_others
     elif name == "my_pending":
         return jobs.my_pending
     elif name == "my_running":
@@ -450,7 +620,51 @@ def __getattr__(name):
         raise AttributeError(f"module '{__name__}' has no attribute '{name}'")
 
 
-__version__ = "0.1.2"
+def __dir__():
+    """Return list of available attributes for tab completion - only essential methods."""
+    return [
+        # Job submission
+        "submit_job",
+        "submit_python",
+        "submit_bash",
+        # Job collections
+        "pending_for_me",
+        "pending_for_others",
+        "jobs_for_me",
+        "jobs_for_others",
+        # Job management
+        "approve",
+        "reject",
+        # Basic monitoring
+        "get_job",
+        "wait_for_completion",
+    ]
+
+
+# Module-level attribute setter to handle VERBOSE flag changes
+
+_this_module = sys.modules[__name__]
+_original_setattr = getattr(_this_module, "__setattr__", None)
+
+
+def _module_setattr(name, value):
+    """Intercept module-level attribute setting to handle VERBOSE flag."""
+    if name == "VERBOSE":
+        global VERBOSE
+        VERBOSE = value
+        _configure_logging()
+    elif _original_setattr:
+        _original_setattr(name, value)
+    else:
+        # Fallback to direct setting
+        globals()[name] = value
+
+
+# Replace the module's __setattr__ method
+setattr(_this_module, "__setattr__", _module_setattr)
+
+
+__version__ = "0.1.26"
 __all__ = [
     # Global unified API
     "jobs",
@@ -458,6 +672,7 @@ __all__ = [
     "jobs_for_others",
     "jobs_for_me",
     "pending_for_me",
+    "pending_for_others",
     "my_pending",
     "my_running",
     "my_completed",
@@ -475,8 +690,14 @@ __all__ = [
     "approve",
     "reject",
     "review_job",
+    "inspect_job",
+    "read_job_file",
+    "list_job_files",
     "status",
     "help",
+    # Logging control
+    "VERBOSE",
+    "set_verbose",
     # Lower-level APIs
     "CodeQueueClient",
     "create_client",
